aboutsummaryrefslogtreecommitdiff
path: root/system
diff options
context:
space:
mode:
authorAlon Zakai <alonzakai@gmail.com>2012-10-19 12:01:13 -0700
committerAlon Zakai <alonzakai@gmail.com>2012-10-19 12:01:13 -0700
commiteeb03b05ad132857a14e081ab6dab4610c8e8f51 (patch)
treef61cf1ebd6261b7fdce940c3f8c42de1c742b1b6 /system
parentc56013b5a9b664b741278536690faeb27b16aa88 (diff)
add argument to emscripten_async_prepare_data
Diffstat (limited to 'system')
-rw-r--r--system/include/emscripten/emscripten.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/system/include/emscripten/emscripten.h b/system/include/emscripten/emscripten.h
index 94f1c860..ed078acd 100644
--- a/system/include/emscripten/emscripten.h
+++ b/system/include/emscripten/emscripten.h
@@ -200,7 +200,7 @@ int emscripten_async_prepare(const char* file, void (*onload)(const char*), void
* Data version of emscripten_async_prepare, which receives
* raw data as input instead of a filename (this can prevent
* the need to write data to a file first). onload and
* onerror are called back with the data pointer as the
* first parameter. onload also receives a second
* parameter, which is a 'fake' filename which you can
* then pass into IMG_Load (it is not an actual file,
@@ -210,7 +210,7 @@ int emscripten_async_prepare(const char* file, void (*onload)(const char*), void
* the fake filename.
* @suffix The file suffix, e.g. 'png' or 'jpg'.
*/
-void emscripten_async_prepare_data(char* data, int size, const char *suffix, void (*onload)(char*, const char*), void (*onerror)(char*));
+void emscripten_async_prepare_data(char* data, int size, const char *suffix, void *arg, void (*onload)(void*, const char*), void (*onerror)(void*));
/*
* Profiling tools.
@@ -200,7 +200,7 @@ int emscripten_async_prepare(const char* file, void (*onload)(const char*), void
* raw data as input instead of a filename (this can prevent
* the need to write data to a file first). onload and
- * onerror are called back with the data pointer as the
+ * onerror are called back with the given arg pointer as the
* first parameter. onload also receives a second
* parameter, which is a 'fake' filename which you can